program JEDISDL2D;

uses
  sdl;

var
  screen : PSDL_Surface;
  image : PSDL_Surface;
  event : TSDL_Event;
  VideoFlags : Uint32 = SDL_SWSURFACE;
  VideoBPP : Uint8 = 0;
  Done : boolean;
  imageRect : TSDL_Rect;
  xmovement : integer;
  ymovement : integer;
  
// function to handle key press events
procedure HandleKeyPress( keysym : PSDL_keysym );
begin
  case keysym.sym of
    SDLK_ESCAPE :
      // ESC key was pressed
      Done := true;

    SDLK_RETURN :
    begin
      if (keysym.Modifier and KMOD_ALT <> 0) then
      begin
        {* Alt+Enter key was pressed
         * this toggles fullscreen mode
         *}
        SDL_WM_ToggleFullScreen( screen );
      end;
    end;
  end;
end;

begin
  // Initialize the video SDL subsystem
  SDL_Init(SDL_INIT_VIDEO); 
  
  // Create a software window of 800x600x16 and assign to screen
  screen := SDL_SetVideoMode( 800, 600, VideoBPP, VideoFlags ); 
 
  // Load our image 
  image := SDL_DisplayFormat( SDL_LoadBMP('JEDI-SDL.bmp') );
  
  // Initialise image position
  imageRect.x := 0;
  imageRect.y := 0;
  imageRect.w := image.w;
  imageRect.h := image.h;
  
  xmovement := 5;
  ymovement := 5;
  
  Done := false;
  while not Done do
  begin
    // Check for events
	while ( SDL_PollEvent(@event) = 1 ) do
	begin
	  case event.type_ of
		
		SDL_KEYDOWN:
		begin
		  // Handle Key presses here
		  HandleKeyPress( @event.key.keysym );
		end;
		
	    SDL_MOUSEMOTION:
		begin
		  // Handle Mouse Motion stuff here
		end;
			  
		SDL_MOUSEBUTTONDOWN:
		begin
		  // Handle Mouse Clicks here
		end;
			  
		SDL_QUITEV:
		begin
		  // Handle user quiting the application
		  Done := true;
		end;
	  end;
	end;
	
	// Move our image around the screen
	if imageRect.x <= 0 then
	  xmovement := 5;
	if imageRect.x > (screen.w - image.w) then
	  xmovement := -5;
	if imageRect.y <= 0 then
	  ymovement := 5;
	if imageRect.y > (screen.h - image.h) then
	  ymovement := -5;
	  
	imageRect.x := imageRect.x + xmovement;
	imageRect.y := imageRect.y + ymovement;
	  
	
	// Draw our image to the screen
	SDL_BlitSurface( image, nil, screen, @imageRect );
	
	// Flip to your back surface
	SDL_Flip( screen );
	// or SDL_UpdateRect(screen, 0, 0, 0, 0); 
  end;
  
  // Free Our resources
  SDL_FreeSurface( image );
  SDL_FreeSurface( screen );
  
  // close the subsystems and SDL;
  SDL_Quit; 
end.
